==> mingw-w64-python-fastapi-0.124.4-1.src.tar.zst: fastapi-0.124.4/docs/ru/docs/deployment/index.md <==
# Развёртывание { #deployment }

Развернуть приложение **FastAPI** довольно просто.

## Что означает развёртывание { #what-does-deployment-mean }

Термин **развёртывание** (приложения) означает выполнение необходимых шагов, чтобы сделать приложение **доступным для пользователей**.

Для **веб-API** это обычно означает размещение его на **удалённой машине** с **серверной программой**, обеспечивающей хорошую производительность, стабильность и т.д., чтобы ваши **пользователи** могли **получать доступ** к приложению эффективно и без перебоев или проблем.

Это отличается от этапов **разработки**, когда вы постоянно меняете код, ломаете его и исправляете, останавливаете и перезапускаете сервер разработки и т.д.

## Стратегии развёртывания { #deployment-strategies }

Есть несколько способов сделать это, в зависимости от вашего конкретного случая и используемых вами инструментов.

Вы можете **развернуть сервер** самостоятельно, используя различные инструменты. Например, можно использовать **облачный сервис**, который выполнит часть работы за вас. Также возможны и другие варианты.

Например, мы, команда, стоящая за FastAPI, создали <a href="https://fastapicloud.com" class="external-link" target="_blank">**FastAPI Cloud**</a>, чтобы сделать развёртывание приложений FastAPI в облаке как можно более простым и прямолинейным, с тем же удобством для разработчика, что и при работе с FastAPI.

В этом блоке я покажу вам некоторые из основных концепций, которые вы, вероятно, должны иметь в виду при развертывании приложения **FastAPI** (хотя большинство из них применимо к любому другому типу веб-приложений).

В последующих разделах вы узнаете больше деталей и методов, необходимых для этого. ✨

==> mingw-w64-python-fastapi-0.133.1-1.src.tar.zst: fastapi-0.133.1/docs/ru/docs/deployment/index.md <==
# Развёртывание { #deployment }

Развернуть приложение **FastAPI** довольно просто.

## Что означает развёртывание { #what-does-deployment-mean }

Термин **развёртывание** (приложения) означает выполнение необходимых шагов, чтобы сделать приложение **доступным для пользователей**.

Для **веб-API** это обычно означает размещение его на **удалённой машине** с **серверной программой**, обеспечивающей хорошую производительность, стабильность и т.д., чтобы ваши **пользователи** могли **получать доступ** к приложению эффективно и без перебоев или проблем.

Это отличается от этапов **разработки**, когда вы постоянно меняете код, ломаете его и исправляете, останавливаете и перезапускаете сервер разработки и т.д.

## Стратегии развёртывания { #deployment-strategies }

Есть несколько способов сделать это, в зависимости от вашего конкретного случая и используемых вами инструментов.

Вы можете **развернуть сервер** самостоятельно, используя различные инструменты. Например, можно использовать **облачный сервис**, который выполнит часть работы за вас. Также возможны и другие варианты.

Например, мы, команда, стоящая за FastAPI, создали <a href="https://fastapicloud.com" class="external-link" target="_blank">**FastAPI Cloud**</a>, чтобы сделать развёртывание приложений FastAPI в облаке как можно более простым и прямолинейным, с тем же удобством для разработчика, что и при работе с FastAPI.

Я покажу вам некоторые из основных концепций, которые вы, вероятно, должны иметь в виду при развертывании приложения **FastAPI** (хотя большинство из них применимо к любому другому типу веб-приложений).

В последующих разделах вы узнаете больше деталей и методов, необходимых для этого. ✨
